@@ -1,7 +1,5 @@
 """Data generation utilities."""
 
-from __future__ import annotations
-
 import itertools
 import json
 import string
@@ -13,9 +11,10 @@ import scipy.signal
 from nibabel import Nifti1Image, gifti
 from scipy.ndimage import binary_dilation
 
-from nilearn import datasets, image, maskers, masking
 from nilearn._utils import logger
 from nilearn._utils.numpy_conversions import as_ndarray
+from nilearn.datasets.struct import load_mni152_brain_mask
+from nilearn.image.image import get_data, new_img_like
 from nilearn.interfaces.bids.utils import (
     bids_entities,
     check_bids_label,
@@ -24,6 +23,8 @@ from nilearn.interfaces.bids.utils import (
 
 # TODO get legal_confounds out of private testing module
 from nilearn.interfaces.fmriprep.tests._testing import get_legal_confound
+from nilearn.maskers.nifti_masker import NiftiMasker
+from nilearn.masking import unmask
 
 
 def generate_mni_space_img(n_scans=1, res=30, random_state=0, mask_dilation=2):
@@ -54,16 +55,14 @@ def generate_mni_space_img(n_scans=1, res=30, random_state=0, mask_dilation=2):
 
     """
     rand_gen = np.random.default_rng(random_state)
-    mask_img = datasets.load_mni152_brain_mask(resolution=res)
-    masker = maskers.NiftiMasker(mask_img).fit()
-    n_voxels = image.get_data(mask_img).sum()
+    mask_img = load_mni152_brain_mask(resolution=res)
+    masker = NiftiMasker(mask_img).fit()
+    n_voxels = get_data(mask_img).sum()
     data = rand_gen.standard_normal((n_scans, n_voxels))
     if mask_dilation is not None and mask_dilation > 0:
-        mask_img = image.new_img_like(
+        mask_img = new_img_like(
             mask_img,
-            binary_dilation(
-                image.get_data(mask_img), iterations=mask_dilation
-            ),
+            binary_dilation(get_data(mask_img), iterations=mask_dilation),
         )
     inverse_img = masker.inverse_transform(data)
     return inverse_img, mask_img
@@ -124,7 +123,7 @@ def generate_regions_ts(
         If True, creates negative and positive valued regions randomly; all
         generated region values are positive otherwise.
 
-        .. versionadded:: 0.11.1
+        .. nilearn_versionadded:: 0.11.1
 
     Returns
     -------
@@ -200,7 +199,7 @@ def generate_maps(
         If True, creates negative and positive valued regions randomly; all
         generated region values are positive otherwise.
 
-        .. versionadded:: 0.11.1
+        .. nilearn_versionadded:: 0.11.1
 
     Returns
     -------
@@ -224,7 +223,7 @@ def generate_maps(
         negative_regions=negative_regions,
     )
     mask_img = Nifti1Image(mask, affine)
-    return masking.unmask(ts, mask_img), mask_img
+    return unmask(ts, mask_img), mask_img
 
 
 def generate_labeled_regions(
@@ -278,7 +277,7 @@ def generate_labeled_regions(
         n_voxels, n_regions, random_state=random_state
     )
     # replace weights with labels
-    for n, row in zip(labels, regions):
+    for n, row in zip(labels, regions, strict=False):
         row[row > 0] = n
     data = np.zeros(shape, dtype=dtype)
     data[np.ones(shape, dtype=bool)] = regions.sum(axis=0).T
@@ -643,7 +642,7 @@ def _generate_signals_from_precisions(
     mean = np.zeros(precisions[0].shape[0])
     signals.extend(
         rand_gen.multivariate_normal(mean, np.linalg.inv(prec), (n,))
-        for n, prec in zip(n_samples, precisions)
+        for n, prec in zip(n_samples, precisions, strict=False)
     )
     return signals
 
@@ -1163,7 +1162,7 @@ def _mock_bids_dataset(
         func_path = subses_dir / "func"
         func_path.mkdir(parents=True, exist_ok=True)
 
-        for task, n_run in zip(tasks, n_runs):
+        for task, n_run in zip(tasks, n_runs, strict=False):
             for run in _listify(n_run):
                 if entities:
                     for key in entities:
@@ -1266,7 +1265,7 @@ def _mock_bids_derivatives(
         func_path = subses_dir / "func"
         func_path.mkdir(parents=True, exist_ok=True)
 
-        for task, n_run in zip(tasks, n_runs):
+        for task, n_run in zip(tasks, n_runs, strict=False):
             for run in _listify(n_run):
                 if entities:
                     for key in entities:
