@@ -1,10 +1,4 @@
-"""
-Test the class_inspect module.
-
-This test file is in nilearn/tests because Nosetest,
-which we historically used,
-ignores modules whose name starts with an underscore.
-"""
+"""Test the class_inspect module."""
 
 import pytest
 
@@ -60,7 +54,8 @@ def test_check_masker_dict_unchanged():
     estimator = DummyEstimator()
 
     with pytest.raises(
-        ValueError, match="Estimator changes '__dict__' keys during transform."
+        ValueError,
+        match=r"Estimator changes '__dict__' keys during 'transform'.",
     ):
         check_img_estimator_dict_unchanged(estimator)
 
