@@ -5,6 +5,7 @@ from math import sqrt
 import numpy as np
 
 from nilearn._utils.docs import fill_doc
+from nilearn._utils.param_validation import check_parameter_in_allowed
 from nilearn.masking import unmask_from_to_3d_array
 
 from ._objective_functions import (
@@ -451,10 +452,7 @@ def _tvl1_objective(X, y, w, alpha, l1_ratio, mask, loss="mse"):
         Value of TV-L1 penalty.
     """
     loss = loss.lower()
-    if loss not in ["mse", "logistic"]:
-        raise ValueError(
-            f"loss must be one of 'mse' or 'logistic'; got '{loss}'"
-        )
+    check_parameter_in_allowed(loss, ["mse", "logistic"], "loss")
 
     if loss == "mse":
         out = squared_loss(X, y, w)
@@ -482,7 +480,7 @@ def tvl1_solver(
     prox_max_iter=5000,
     tol=1e-4,
     callback=None,
-    verbose=1,
+    verbose=0,
 ):
     """Minimizes empirical risk for TV-L1 penalized models.
 
@@ -529,10 +527,12 @@ def tvl1_solver(
         of the energy being minimized. If no value is specified (None),
         then it will be calculated.
 
-    callback : callable(dict) -> bool, default=None
+    callback : callable(dict) -> :obj:`bool`, default=None
         Function called at the end of every energy descendent iteration of the
         solver. If it returns True, the loop breaks.
 
+    %(verbose0)s
+
     Returns
     -------
     w : ndarray, shape (n_features,)
@@ -546,11 +546,7 @@ def tvl1_solver(
         Solver information, for warm start.
 
     """
-    # sanitize loss
-    if loss not in ["mse", "logistic"]:
-        raise ValueError(
-            f"'{loss}' loss not implemented. Should be 'mse' or 'logistic"
-        )
+    check_parameter_in_allowed(loss, ["mse", "logistic"], "loss")
 
     # shape of image box
     flat_mask = mask.ravel()
