@@ -55,10 +55,6 @@ from nilearn._utils.estimator_checks import (
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.param_validation import (
-    _get_mask_extent,
-    check_feature_screening,
-)
 from nilearn._utils.tags import SKLEARN_LT_1_6
 from nilearn.conftest import _rng
 from nilearn.decoding import (
@@ -67,6 +63,10 @@ from nilearn.decoding import (
     FREMClassifier,
     FREMRegressor,
 )
+from nilearn.decoding._utils import (
+    _get_mask_extent,
+    check_feature_screening,
+)
 from nilearn.decoding.decoder import (
     SUPPORTED_ESTIMATORS,
     _BaseDecoder,
@@ -84,10 +84,10 @@ ESTIMATOR_REGRESSION = ("ridge", "svr")
 
 
 ESTIMATORS_TO_CHECK = [
-    Decoder(),
-    DecoderRegressor(),
-    FREMClassifier(),
-    FREMRegressor(),
+    Decoder(standardize="zscore_sample", screening_percentile=100),
+    DecoderRegressor(standardize="zscore_sample", screening_percentile=100),
+    FREMClassifier(standardize="zscore_sample", screening_percentile=100),
+    FREMRegressor(standardize="zscore_sample", screening_percentile=100),
 ]
 
 if SKLEARN_LT_1_6:
@@ -120,6 +120,7 @@ else:
         check(estimator)
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "estimator, check, name",
     nilearn_check_estimator(estimators=ESTIMATORS_TO_CHECK),
@@ -275,7 +276,7 @@ def test_non_supported_estimator_error(rand_x_y, estimator):
     X, Y = rand_x_y
 
     with pytest.raises(
-        ValueError, match="Invalid estimator. The supported estimators are:"
+        TypeError, match=r"Invalid estimator. The supported estimators are:"
     ):
         _check_param_grid(estimator, X, Y, None)
 
@@ -366,7 +367,9 @@ def test_check_inputs_length(model):
     y = y[:-10]
 
     with pytest.raises(ValueError, match="inconsistent numbers of samples"):
-        model(mask=mask, screening_percentile=100.0).fit(X_, y)
+        model(
+            mask=mask, screening_percentile=100.0, standardize="zscore_sample"
+        ).fit(X_, y)
 
 
 @pytest.mark.parametrize(
@@ -394,7 +397,11 @@ def test_check_supported_estimator(estimator):
     )
 
     with warnings.catch_warnings(record=True) as raised_warnings:
-        _check_estimator(_BaseDecoder(estimator=estimator).estimator)
+        _check_estimator(
+            _BaseDecoder(
+                estimator=estimator, standardize="zscore_sample"
+            ).estimator
+        )
     warning_messages = [str(warning.message) for warning in raised_warnings]
 
     assert expected_warning not in warning_messages
@@ -408,7 +415,11 @@ def test_check_unsupported_estimator(estimator):
     then raise the error.
     """
     with pytest.raises(ValueError, match="Invalid estimator"):
-        _check_estimator(_BaseDecoder(estimator=estimator).estimator)
+        _check_estimator(
+            _BaseDecoder(
+                estimator=estimator, standardize="zscore_sample"
+            ).estimator
+        )
 
     expected_warning = (
         "Use a custom estimator at your own risk "
@@ -416,7 +427,11 @@ def test_check_unsupported_estimator(estimator):
     )
     custom_estimator = RandomForestClassifier()
     with pytest.warns(UserWarning, match=expected_warning):
-        _check_estimator(_BaseDecoder(estimator=custom_estimator).estimator)
+        _check_estimator(
+            _BaseDecoder(
+                estimator=custom_estimator, standardize="zscore_sample"
+            ).estimator
+        )
 
 
 def test_parallel_fit(rand_x_y):
@@ -467,7 +482,7 @@ def test_parallel_fit(rand_x_y):
         )
 
     # check that every element of the output tuple is the same for both tries
-    for a, b in zip(outputs[0], outputs[1]):
+    for a, b in zip(outputs[0], outputs[1], strict=False):
         if isinstance(a, np.ndarray):
             assert_array_almost_equal(a, b)
         else:
@@ -565,7 +580,9 @@ def test_decoder_param_grid_sequence(binary_classification_data):
         },
     ]
 
-    model = Decoder(param_grid=param_grid, cv=n_cv_folds)
+    model = Decoder(
+        param_grid=param_grid, cv=n_cv_folds, standardize="zscore_sample"
+    )
     model.fit(X, y)
 
     for best_params in model.cv_params_.values():
@@ -579,7 +596,7 @@ def test_decoder_binary_classification_with_masker_object(
 ):
     X, y, _ = binary_classification_data
 
-    model = Decoder(mask=NiftiMasker())
+    model = Decoder(mask=NiftiMasker(), standardize="zscore_sample")
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -595,7 +612,9 @@ def test_decoder_binary_classification_with_logistic_model(
     """Check decoder with predict_proba for scoring with logistic model."""
     X, y, mask = binary_classification_data
 
-    model = Decoder(estimator="logistic_l2", mask=mask)
+    model = Decoder(
+        estimator="logistic_l2", mask=mask, standardize="zscore_sample"
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -609,7 +628,11 @@ def test_decoder_binary_classification_screening(
 ):
     X, y, mask = binary_classification_data
 
-    model = Decoder(mask=mask, screening_percentile=screening_percentile)
+    model = Decoder(
+        mask=mask,
+        screening_percentile=screening_percentile,
+        standardize="zscore_sample",
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -629,6 +652,7 @@ def test_decoder_binary_classification_clustering(
         clustering_percentile=clustering_percentile,
         screening_percentile=90,
         cv=5,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -637,26 +661,63 @@ def test_decoder_binary_classification_clustering(
 
 
 @ignore_warnings
-@pytest.mark.parametrize("cv", [KFold(n_splits=5), LeaveOneGroupOut()])
-def test_decoder_binary_classification_cross_validation(
-    binary_classification_data, cv, rng
-):
-    X, y, mask = binary_classification_data
+@pytest.mark.slow
+@pytest.mark.parametrize(
+    "estimator, data",
+    [
+        (Decoder, _make_binary_classification_test_data(n_samples=N_SAMPLES)),
+        (
+            Decoder,
+            _make_multiclass_classification_test_data(n_samples=N_SAMPLES),
+        ),
+        (
+            DecoderRegressor,
+            _make_regression_test_data(n_samples=N_SAMPLES, dim=5),
+        ),
+        (
+            FREMClassifier,
+            _make_binary_classification_test_data(n_samples=N_SAMPLES),
+        ),
+        (
+            FREMClassifier,
+            _make_multiclass_classification_test_data(n_samples=N_SAMPLES),
+        ),
+        (
+            FREMRegressor,
+            _make_regression_test_data(n_samples=N_SAMPLES, dim=5),
+        ),
+    ],
+)
+@pytest.mark.parametrize("cv", [KFold(n_splits=5), LeaveOneGroupOut(), None])
+def test_cross_validation(estimator, data, cv):
+    """Check cross-validation scheme and fit attribute with groups enabled."""
+    X, y, mask = data
+
+    model = estimator(mask=mask, cv=cv)
 
-    # check cross-validation scheme and fit attribute with groups enabled
-    model = Decoder(
-        estimator="svc", mask=mask, standardize="zscore_sample", cv=cv
-    )
     groups = None
     if isinstance(cv, LeaveOneGroupOut):
-        groups = rng.binomial(2, 0.3, size=len(y))
+        groups = _rng(0).binomial(2, 0.3, size=len(y))
     model.fit(X, y, groups=groups)
+
     y_pred = model.predict(X)
 
-    assert accuracy_score(y, y_pred) > 0.9
+    # fall on default of 10 fold (30 for the FREM) when cv is None
+    if cv is None:
+        n_cv = len(model.cv_)
+        if isinstance(model, (Decoder, DecoderRegressor)):
+            assert n_cv == 10
+        else:
+            assert n_cv == 30
+
+    if isinstance(model, (Decoder)):
+        assert accuracy_score(y, y_pred) > 0.9
+    elif isinstance(model, (DecoderRegressor)):
+        assert r2_score(y, y_pred) > 0.9
 
 
 @ignore_warnings
+@pytest.mark.slow
 def test_decoder_dummy_classifier(binary_classification_data):
     n_samples = N_SAMPLES
     X, y, mask = binary_classification_data
@@ -667,7 +728,9 @@ def test_decoder_dummy_classifier(binary_classification_data):
     y = np.zeros(n_samples)
     y[: int(proportion * n_samples)] = 1.0
 
-    model = Decoder(estimator="dummy_classifier", mask=mask)
+    model = Decoder(
+        estimator="dummy_classifier", mask=mask, standardize="zscore_sample"
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -680,7 +743,10 @@ def test_decoder_dummy_classifier_with_callable(binary_classification_data):
 
     accuracy_scorer = get_scorer("accuracy")
     model = Decoder(
-        estimator="dummy_classifier", mask=mask, scoring=accuracy_scorer
+        estimator="dummy_classifier",
+        mask=mask,
+        scoring=accuracy_scorer,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -696,7 +762,9 @@ def test_decoder_dummy_classifier_strategy_prior():
     param = {"strategy": "prior"}
     dummy_classifier = DummyClassifier(random_state=0)
     dummy_classifier.set_params(**param)
-    model = Decoder(estimator=dummy_classifier, mask=mask)
+    model = Decoder(
+        estimator=dummy_classifier, mask=mask, standardize="zscore_sample"
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -712,7 +780,9 @@ def test_decoder_dummy_classifier_strategy_most_frequent():
     dummy_classifier = DummyClassifier(random_state=0)
     dummy_classifier.set_params(**param)
 
-    model = Decoder(estimator=dummy_classifier, mask=mask)
+    model = Decoder(
+        estimator=dummy_classifier, mask=mask, standardize="zscore_sample"
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -729,7 +799,12 @@ def test_decoder_dummy_classifier_strategy_most_frequent():
 def test_decoder_dummy_classifier_roc_scoring(binary_classification_data):
     X, y, mask = binary_classification_data
 
-    model = Decoder(estimator="dummy_classifier", mask=mask, scoring="roc_auc")
+    model = Decoder(
+        estimator="dummy_classifier",
+        mask=mask,
+        scoring="roc_auc",
+        standardize="zscore_sample",
+    )
     model.fit(X, y)
 
     assert np.mean(model.cv_scores_[0]) >= 0.45
@@ -743,7 +818,9 @@ def test_decoder_error_not_implemented(tiny_binary_classification_data):
     dummy_classifier = DummyClassifier(random_state=0)
     dummy_classifier.set_params(**param)
 
-    model = Decoder(estimator=dummy_classifier, mask=mask)
+    model = Decoder(
+        estimator=dummy_classifier, mask=mask, standardize="zscore_sample"
+    )
 
     with pytest.raises(NotImplementedError):
         model.fit(X, y)
@@ -757,7 +834,12 @@ def test_decoder_error_unknown_scoring_metrics(
 
     dummy_classifier = DummyClassifier(random_state=0)
 
-    model = Decoder(estimator=dummy_classifier, mask=mask, scoring="foo")
+    model = Decoder(
+        estimator=dummy_classifier,
+        mask=mask,
+        scoring="foo",
+        standardize="zscore_sample",
+    )
 
     with pytest.raises(
         ValueError,
@@ -770,7 +852,9 @@ def test_decoder_error_unknown_scoring_metrics(
 def test_decoder_dummy_classifier_default_scoring():
     X, y, _ = _make_binary_classification_test_data()
 
-    model = Decoder(estimator="dummy_classifier", scoring=None)
+    model = Decoder(
+        estimator="dummy_classifier", scoring=None, standardize="zscore_sample"
+    )
 
     assert model.scoring is None
 
@@ -789,7 +873,7 @@ def test_decoder_classification_string_label():
     labels = ["red", "blue", "green"]
     y_str = [labels[y[i]] for i in range(len(y))]
 
-    model = Decoder(mask=mask)
+    model = Decoder(mask=mask, standardize="zscore_sample")
     model.fit(X, y_str)
     y_pred = model.predict(X)
 
@@ -808,6 +892,7 @@ def test_decoder_regression_screening(
         estimator=estimator,
         mask=mask,
         screening_percentile=screening_percentile,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -829,6 +914,7 @@ def test_decoder_regression_clustering(
         clustering_percentile=clustering_percentile,
         screening_percentile=90,
         cv=10,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -848,6 +934,7 @@ def test_decoder_dummy_regression(regression_data):
         mask=mask,
         scoring="r2",
         screening_percentile=1,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -865,7 +952,10 @@ def test_decoder_dummy_regression_default_scoring_metric_is_r2(
     X, y, mask = regression_data
 
     model = DecoderRegressor(
-        estimator="dummy_regressor", mask=mask, scoring=None
+        estimator="dummy_regressor",
+        mask=mask,
+        scoring=None,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -882,7 +972,9 @@ def test_decoder_dummy_regression_other_strategy(regression_data):
     param = {"strategy": "median"}
     dummy_regressor.set_params(**param)
 
-    model = DecoderRegressor(estimator=dummy_regressor, mask=mask)
+    model = DecoderRegressor(
+        estimator=dummy_regressor, mask=mask, standardize="zscore_sample"
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -895,10 +987,11 @@ def test_decoder_dummy_regression_other_strategy(regression_data):
 
 
 @ignore_warnings
+@pytest.mark.slow
 def test_decoder_multiclass_classification_masker(multiclass_data):
     X, y, _ = multiclass_data
 
-    model = Decoder(mask=NiftiMasker())
+    model = Decoder(mask=NiftiMasker(), standardize="zscore_sample")
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -912,7 +1005,10 @@ def test_decoder_multiclass_classification_masker_dummy_classifier(
     X, y, _ = multiclass_data
 
     model = Decoder(
-        estimator="dummy_classifier", mask=NiftiMasker(), scoring="accuracy"
+        estimator="dummy_classifier",
+        mask=NiftiMasker(),
+        scoring="accuracy",
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -924,13 +1020,18 @@ def test_decoder_multiclass_classification_masker_dummy_classifier(
 
 
 @ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("screening_percentile", [100, 20, None])
 def test_decoder_multiclass_classification_screening(
     multiclass_data, screening_percentile
 ):
     X, y, mask = multiclass_data
 
-    model = Decoder(mask=mask, screening_percentile=screening_percentile)
+    model = Decoder(
+        mask=mask,
+        screening_percentile=screening_percentile,
+        standardize="zscore_sample",
+    )
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -938,6 +1039,7 @@ def test_decoder_multiclass_classification_screening(
 
 
 @ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("clustering_percentile", [100, 99])
 @pytest.mark.parametrize("estimator", ["svc_l2", "svc_l1"])
 def test_decoder_multiclass_classification_clustering(
@@ -951,6 +1053,7 @@ def test_decoder_multiclass_classification_clustering(
         clustering_percentile=clustering_percentile,
         screening_percentile=90,
         cv=5,
+        standardize="zscore_sample",
     )
     model.fit(X, y)
     y_pred = model.predict(X)
@@ -959,26 +1062,6 @@ def test_decoder_multiclass_classification_clustering(
     assert accuracy_score(y, y_pred) > 0.9
 
 
-@ignore_warnings
-@pytest.mark.parametrize("cv", [KFold(n_splits=5), LeaveOneGroupOut()])
-def test_decoder_multiclass_classification_cross_validation(
-    multiclass_data, cv
-):
-    X, y, mask = multiclass_data
-
-    # check cross-validation scheme and fit attribute with groups enabled
-    model = Decoder(
-        estimator="svc", mask=mask, standardize="zscore_sample", cv=cv
-    )
-    groups = None
-    if isinstance(cv, LeaveOneGroupOut):
-        groups = _rng(0).binomial(2, 0.3, size=len(y))
-    model.fit(X, y, groups=groups)
-    y_pred = model.predict(X)
-
-    assert accuracy_score(y, y_pred) > 0.9
-
-
 def test_decoder_multiclass_classification_apply_mask_shape():
     """Test whether if _apply mask output has the same shape \
     as original matrix.
@@ -994,7 +1077,7 @@ def test_decoder_multiclass_classification_apply_mask_shape():
     )
     X, _ = to_niimgs(X_init, [dim, dim, dim])
 
-    model = Decoder(mask=NiftiMasker())
+    model = Decoder(mask=NiftiMasker(), standardize="zscore_sample")
 
     X_masked = model._apply_mask(X)
 
@@ -1023,6 +1106,7 @@ def test_decoder_multiclass_classification_apply_mask_attributes(affine_eye):
         high_pass=high_pass,
         low_pass=low_pass,
         smoothing_fwhm=smoothing_fwhm,
+        standardize="zscore_sample",
     )
 
     model._apply_mask(X)
@@ -1040,29 +1124,36 @@ def test_decoder_multiclass_error_incorrect_cv(multiclass_data):
     X, y, _ = multiclass_data
 
     for cv in ["abc", LinearSVC(dual=True)]:
-        model = Decoder(mask=NiftiMasker(), cv=cv)
+        model = Decoder(mask=NiftiMasker(), cv=cv, standardize="zscore_sample")
         with pytest.raises(ValueError, match="Expected cv as an integer"):
             model.fit(X, y)
 
 
 @ignore_warnings
-def test_decoder_multiclass_warnings(multiclass_data):
+def test_decoder_multiclass_warnings_decoder(multiclass_data):
+    """Check whether decoder raised warning \
+        when groups is set to specific value but CV Splitter is not set.
+    """
     X, y, _ = multiclass_data
     groups = _rng(0).binomial(2, 0.3, size=len(y))
 
-    # Check whether decoder raised warning when groups is set to specific
-    # value but CV Splitter is not set
     expected_warning = (
         "groups parameter is specified but "
         "cv parameter is not set to custom CV splitter. "
         "Using default object LeaveOneGroupOut()."
     )
     with pytest.warns(UserWarning, match=expected_warning):
-        model = Decoder(mask=NiftiMasker())
+        model = Decoder(mask=NiftiMasker(), standardize="zscore_sample")
         model.fit(X, y, groups=groups)
 
-    # Check that warning is raised when n_features is lower than 50 after
-    # screening and clustering for FREM
+
+@ignore_warnings
+def test_decoder_multiclass_warnings_frem(multiclass_data):
+    """Check that warning is raised \
+        when n_features is lower than 50 after \
+        screening and clustering.
+    """
+    X, y, _ = multiclass_data
     with pytest.warns(
         UserWarning, match=".*decoding model will be trained only.*"
     ):
@@ -1071,6 +1162,7 @@ def test_decoder_multiclass_warnings(multiclass_data):
             screening_percentile=10,
             mask=NiftiMasker(),
             cv=1,
+            standardize="zscore_sample",
         )
         model.fit(X, y)
 
@@ -1096,7 +1188,7 @@ def test_decoder_tags_regression():
 
 
 @ignore_warnings
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 def test_decoder_strings_filepaths_input(
     tiny_binary_classification_data, tmp_path
 ):
@@ -1109,7 +1201,7 @@ def test_decoder_strings_filepaths_input(
     for i, nii_path in enumerate(X_paths):
         save(X.slicer[..., i], nii_path)
 
-    model = Decoder(mask=NiftiMasker())
+    model = Decoder(mask=NiftiMasker(), standardize="zscore_sample")
     model.fit(X_paths, y)
     model.predict(X_paths)
     model.score(X_paths, y)
@@ -1135,7 +1227,7 @@ def _make_surface_reg_data(rng, surf_img_2d, n_samples=50):
 def test_decoder_apply_mask_surface(_make_surface_class_data):
     """Test _apply_mask on surface image."""
     X, _ = _make_surface_class_data
-    model = Decoder(mask=SurfaceMasker())
+    model = Decoder(mask=SurfaceMasker(), standardize="zscore_sample")
     X_masked = model._apply_mask(X)
 
     assert X_masked.shape == X.shape[::-1]
@@ -1149,7 +1241,7 @@ def test_decoder_screening_percentile_surface_default(
     """Test default screening percentile with surface image."""
     X, y = _make_surface_class_data
 
-    model = Decoder(mask=SurfaceMasker())
+    model = Decoder(mask=SurfaceMasker(), standardize="zscore_sample")
     model.fit(X, y)
     assert model.screening_percentile_ == 20
 
@@ -1160,7 +1252,11 @@ def test_decoder_screening_percentile_surface(perc, _make_surface_class_data):
     """Test passing screening percentile with surface image."""
     X, y = _make_surface_class_data
 
-    model = Decoder(mask=SurfaceMasker(), screening_percentile=perc)
+    model = Decoder(
+        mask=SurfaceMasker(),
+        screening_percentile=perc,
+        standardize="zscore_sample",
+    )
     model.fit(X, y)
     if perc is None:
         assert model.screening_percentile_ == 100
@@ -1191,6 +1287,7 @@ def test_decoder_adjust_screening_less_than_mask_surface(
         param_grid={"C": [0.01, 0.1]},
         cv=3,
         screening_percentile=screening_percentile,
+        standardize="zscore_sample",
     )
     decoder.fit(img, y)
     adjusted = decoder.screening_percentile_
@@ -1222,6 +1319,7 @@ def test_decoder_adjust_screening_greater_than_mask_surface(
         param_grid={"C": [0.01, 0.1]},
         cv=3,
         screening_percentile=screening_percentile,
+        standardize="zscore_sample",
     )
     decoder.fit(img, y)
     adjusted = decoder.screening_percentile_
@@ -1232,7 +1330,7 @@ def test_decoder_adjust_screening_greater_than_mask_surface(
 def test_decoder_predict_score_surface(_make_surface_class_data):
     """Test classification predict and scoring for surface image."""
     X, y = _make_surface_class_data
-    model = Decoder(mask=SurfaceMasker())
+    model = Decoder(mask=SurfaceMasker(), standardize="zscore_sample")
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -1247,7 +1345,7 @@ def test_decoder_predict_score_surface(_make_surface_class_data):
 def test_decoder_regressor_predict_score_surface(_make_surface_reg_data):
     """Test regression predict and scoring for surface image."""
     X, y = _make_surface_reg_data
-    model = DecoderRegressor(mask=SurfaceMasker())
+    model = DecoderRegressor(mask=SurfaceMasker(), standardize="zscore_sample")
     model.fit(X, y)
     y_pred = model.predict(X)
 
@@ -1267,7 +1365,11 @@ def test_frem_decoder_fit_surface(
 ):
     """Test fit for using FREM decoding with surface image."""
     X, y = _make_surface_class_data
-    model = frem(mask=surf_mask_1d, clustering_percentile=90)
+    model = frem(
+        mask=surf_mask_1d,
+        clustering_percentile=90,
+        standardize="zscore_sample",
+    )
     model.fit(X, y)
 
 
@@ -1275,7 +1377,7 @@ def test_frem_decoder_fit_surface(
 
 
 @ignore_warnings
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "classifier_penalty",
     ["svc_l1", "svc_l2", "logistic_l1", "logistic_l2", "ridge_classifier"],
@@ -1294,11 +1396,11 @@ def test_decoder_vs_sklearn(
     # default scoring is accuracy
     scorer = check_scoring(strings_to_sklearn[classifier_penalty], "accuracy")
 
-    ## nilearn decoding
+    # nilearn decoding
     nilearn_decoder = Decoder(
         estimator=classifier_penalty,
         mask=mask,
-        standardize=True,
+        standardize="zscore_sample",
         cv=cv,
         scoring=scorer,
         screening_percentile=100,  # disable screening
@@ -1306,8 +1408,8 @@ def test_decoder_vs_sklearn(
     nilearn_decoder.fit(X, y)
     scores_nilearn = nilearn_decoder.cv_scores_
 
-    ## start decoding with sklearn
-    masker = NiftiMasker(mask_img=mask, standardize=True)
+    # start decoding with sklearn
+    masker = NiftiMasker(mask_img=mask, standardize="zscore_sample")
     X_transformed = masker.fit_transform(X)
 
     sklearn_classifier = strings_to_sklearn[classifier_penalty]
@@ -1371,6 +1473,7 @@ def _set_best_hyperparameters(
 
 
 @ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("regressor", ["svr", "lasso", "ridge"])
 def test_regressor_vs_sklearn(
     regressor, strings_to_sklearn=SUPPORTED_ESTIMATORS
@@ -1384,11 +1487,11 @@ def test_regressor_vs_sklearn(
     # r2 is the default scoring for regression
     scorer = check_scoring(strings_to_sklearn[regressor], "r2")
 
-    ## nilearn decoding
+    # nilearn decoding
     nilearn_regressor = DecoderRegressor(
         estimator=regressor,
         mask=mask,
-        standardize=True,
+        standardize="zscore_sample",
         cv=cv,
         scoring=scorer,
         screening_percentile=100,  # disable screening
@@ -1396,8 +1499,8 @@ def test_regressor_vs_sklearn(
     nilearn_regressor.fit(X, y)
     scores_nilearn = nilearn_regressor.cv_scores_["beta"]
 
-    ## start decoding with sklearn
-    masker = NiftiMasker(mask_img=mask, standardize=True)
+    # start decoding with sklearn
+    masker = NiftiMasker(mask_img=mask, standardize="zscore_sample")
     X_transformed = masker.fit_transform(X)
 
     sklearn_regressor = strings_to_sklearn[regressor]
