@@ -13,9 +13,13 @@ See an example below:
 
 """
 
+import re
+
 import numpy as np
 import pandas as pd
 
+from nilearn._utils.param_validation import check_parameter_in_allowed
+
 from .load_confounds_compcor import find_compcor
 from .load_confounds_scrub import optimize_scrub
 from .load_confounds_utils import (
@@ -26,6 +30,116 @@ from .load_confounds_utils import (
 )
 
 
+def _tedana_strategy(classification, mixing, metrics):
+    """
+    Auxiliary functionality to extract confounds based on the strategy.
+
+    Parameters
+    ----------
+    classification : :obj:`list`
+        list of classifications to be returned from the mixing file
+
+    mixing : :obj:`pd.DataFrame`
+        pandas dataframe with the mixing file.
+
+    metrics : :obj:`pd.DataFrame`
+        pandas dataframe with the metrics file.
+
+    Returns
+    -------
+    pandas.DataFrame
+        DataFrame of TEDANA regressors.
+    """
+    # Get selected components from status table
+    selected_metric_components = metrics[
+        metrics["classification"].isin(classification)
+    ]
+
+    #############################################################
+    # tedana versions like 24.0.2 do not have matching component
+    # names from the mixing and status tables. For backwards
+    # compatibility we will normalize the component names to
+    # match the mixing file rejected component
+    # names: ICA_04 -> ICA_4
+    #############################################################
+
+    # Normalize mixing file column names and build a mapping
+    original_columns = mixing.columns.tolist()
+
+    # Map: normalized_name -> original_name
+    column_mapping = {
+        re.sub(r"ICA_0*(\d+)$", lambda m: f"ICA_{int(m.group(1))}", col): col
+        for col in original_columns
+    }
+
+    # Apply normalized names to columns
+    mixing.columns = list(column_mapping.keys())
+
+    # Build classification lookup from normalized component names
+    classification_lookup = {
+        re.sub(
+            r"ICA_0*(\d+)$",
+            lambda m: f"ICA_{int(m.group(1))}",
+            row["Component"],
+        ): row["classification"]
+        for _, row in selected_metric_components.iterrows()
+    }
+
+    # Select matched columns (normalized)
+    matched_components = [
+        c for c in classification_lookup if c in mixing.columns
+    ]
+    selected = mixing[sorted(matched_components)]
+
+    # Rename columns using classification + original name
+    # we are prefixing the classification value to the column name
+    # regardless of the tedana strategy selected
+    renamed_columns = {
+        col: f"{classification_lookup[col]}_{column_mapping[col]}"
+        for col in selected.columns
+    }
+
+    return selected.rename(columns=renamed_columns)
+
+
+def _load_tedana(confounds_files, tedana):
+    """Load the TEDANA regressors.
+
+    Parameters
+    ----------
+    confounds_files : :obj:`dict`
+        dict of confounds dataframes.
+
+    tedana : str
+        TEDANA strategy to use. Options are "aggressive" or
+        "non-aggressive".
+
+    Returns
+    -------
+    pandas.DataFrame
+        DataFrame of TEDANA regressors.
+    """
+    if tedana not in ["aggressive", "non-aggressive"]:
+        raise ValueError(
+            "Please select a valid option 'aggresive' or 'non-aggressive' "
+            "when using TEDANA strategy. "
+            f"Current input: {tedana}"
+        )
+
+    if tedana == "aggressive":
+        return _tedana_strategy(
+            ["rejected"],
+            mixing=confounds_files["mixing"],
+            metrics=confounds_files["metrics"],
+        )
+    elif tedana == "non-aggressive":
+        return _tedana_strategy(
+            ["accepted", "rejected"],
+            mixing=confounds_files["mixing"],
+            metrics=confounds_files["metrics"],
+        )
+
+
 def _load_motion(confounds_raw, motion):
     """Load the motion regressors.
 
@@ -206,6 +320,7 @@ def _load_ica_aroma(confounds_raw, ica_aroma):
     ValueError
         When ica_aroma is not "full" or "basic".
     """
+    check_parameter_in_allowed(ica_aroma, ("full", "basic"), "ica_aroma")
     if ica_aroma == "full":
         return pd.DataFrame()
     elif ica_aroma == "basic":
@@ -213,11 +328,6 @@ def _load_ica_aroma(confounds_raw, ica_aroma):
         if not ica_aroma_params:
             raise MissingConfoundError(keywords=["ica_aroma"])
         return confounds_raw[ica_aroma_params]
-    else:
-        raise ValueError(
-            "Please select an option when using ICA-AROMA strategy."
-            f"Current input: {ica_aroma}"
-        )
 
 
 def _load_scrub(confounds_raw, scrub, fd_threshold, std_dvars_threshold):
@@ -288,5 +398,7 @@ def _load_non_steady_state(confounds_raw):
         DataFrame of non steady state regressors generated by fMRIPrep.
         If none were found, return an empty DataFrame.
     """
+    if isinstance(confounds_raw, dict):
+        return pd.DataFrame()
     nss_outliers = find_confounds(confounds_raw, ["non_steady_state"])
     return confounds_raw[nss_outliers] if nss_outliers else pd.DataFrame()
