@@ -1,20 +1,16 @@
 """Masker for surface objects."""
 
-from __future__ import annotations
-
 from copy import deepcopy
 from warnings import warn
 
 import numpy as np
+from sklearn.base import ClassNamePrefixFeaturesOutMixin
 from sklearn.utils.estimator_checks import check_is_fitted
 
 from nilearn import DEFAULT_SEQUENTIAL_CMAP, signal
 from nilearn._utils.class_inspect import get_params
 from nilearn._utils.docs import fill_doc
-from nilearn._utils.helpers import (
-    constrained_layout_kwargs,
-    rename_parameters,
-)
+from nilearn._utils.helpers import is_matplotlib_installed
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.masker_validation import (
     check_compatibility_mask_and_images,
@@ -27,10 +23,10 @@ from nilearn.surface.utils import check_polymesh_equal
 
 
 @fill_doc
-class SurfaceMasker(_BaseSurfaceMasker):
+class SurfaceMasker(ClassNamePrefixFeaturesOutMixin, _BaseSurfaceMasker):
     """Extract data from a :obj:`~nilearn.surface.SurfaceImage`.
 
-    .. versionadded:: 0.11.0
+    .. nilearn_versionadded:: 0.11.0
 
     Parameters
     ----------
@@ -39,7 +35,7 @@ class SurfaceMasker(_BaseSurfaceMasker):
     %(smoothing_fwhm)s
         This parameter is not implemented yet.
 
-    %(standardize_maskers)s
+    %(standardize_false)s
 
     %(standardize_confounds)s
 
@@ -122,7 +118,7 @@ class SurfaceMasker(_BaseSurfaceMasker):
         self.reports = reports
         self.cmap = cmap
         self.clean_args = clean_args
-        # content to inject in the HTML template
+
         self._report_content = {
             "description": (
                 "This report shows the input surface image overlaid "
@@ -133,13 +129,11 @@ class SurfaceMasker(_BaseSurfaceMasker):
             "n_vertices": {},
             # unused but required in HTML template
             "number_of_regions": None,
-            "summary": None,
-            "warning_message": None,
+            "summary": {},
+            "warning_messages": [],
             "n_elements": 0,
             "coverage": 0,
         }
-        # data necessary to construct figure for the report
-        self._reporting_data = None
 
     def __sklearn_is_fitted__(self):
         return (
@@ -163,7 +157,7 @@ class SurfaceMasker(_BaseSurfaceMasker):
                 warn(
                     f"[{self.__class__.__name__}.fit] "
                     "Generation of a mask has been"
-                    " requested (y != None) while a mask was"
+                    " requested (img != None) while a mask was"
                     " given at masker creation. Given mask"
                     " will be used.",
                     stacklevel=find_stack_level(),
@@ -200,10 +194,6 @@ class SurfaceMasker(_BaseSurfaceMasker):
                 )
         self.mask_img_ = SurfaceImage(mesh=img.mesh, data=mask_data)
 
-    # TODO (nilearn >= 0.13.0)
-    @rename_parameters(
-        replacement_params={"img": "imgs"}, end_version="0.13.0"
-    )
     @fill_doc
     def fit(self, imgs=None, y=None):
         """Prepare signal extraction from regions.
@@ -224,9 +214,28 @@ class SurfaceMasker(_BaseSurfaceMasker):
         """
         del y
         check_params(self.__dict__)
+
+        # Reset warning message
+        # in case where the masker was previously fitted
+        self._report_content["warning_messages"] = []
+
         if imgs is not None:
             self._check_imgs(imgs)
 
+            if isinstance(imgs, SurfaceImage) and any(
+                hemi.ndim > 2 for hemi in imgs.data.parts.values()
+            ):
+                raise ValueError(
+                    "should only be SurfaceImage should 1D or 2D."
+                )
+            elif hasattr(imgs, "__iter__"):
+                for i, x in enumerate(imgs):
+                    x.data._check_n_samples(1, f"imgs[{i}]")
+
+        return self._fit(imgs)
+
+    def _fit(self, imgs):
+        """Keep private to call it with MultiSurfaceMasker too."""
         self._fit_cache()
 
         self._fit_mask_img(imgs)
@@ -240,6 +249,7 @@ class SurfaceMasker(_BaseSurfaceMasker):
             start = stop
         self.n_elements_ = int(stop)
 
+        self._report_content["reports_at_fit_time"] = self.reports
         if self.reports:
             self._report_content["n_elements"] = self.n_elements_
             for part in self.mask_img_.data.parts:
@@ -291,9 +301,16 @@ class SurfaceMasker(_BaseSurfaceMasker):
         check_is_fitted(self)
 
         check_compatibility_mask_and_images(self.mask_img_, imgs)
-
         check_polymesh_equal(self.mask_img_.mesh, imgs.mesh)
 
+        if isinstance(imgs, SurfaceImage) and any(
+            hemi.ndim > 2 for hemi in imgs.data.parts.values()
+        ):
+            raise ValueError("should only be SurfaceImage should 1D or 2D.")
+        elif hasattr(imgs, "__iter__"):
+            for i, x in enumerate(imgs):
+                x.data._check_n_samples(1, f"imgs[{i}]")
+
         if self.reports:
             self._reporting_data["images"] = imgs
 
@@ -363,18 +380,7 @@ class SurfaceMasker(_BaseSurfaceMasker):
 
         return SurfaceImage(mesh=self.mask_img_.mesh, data=data)
 
-    def generate_report(self):
-        """Generate a report for the SurfaceMasker.
-
-        Returns
-        -------
-        list(None) or HTMLReport
-        """
-        from nilearn.reporting.html_report import generate_report
-
-        return generate_report(self)
-
-    def _reporting(self):
+    def _reporting(self) -> None | str:
         """Load displays needed for report.
 
         Returns
@@ -383,94 +389,64 @@ class SurfaceMasker(_BaseSurfaceMasker):
             A list of all displays figures encoded as bytes to be rendered.
             Or a list with a single None element.
         """
-        # avoid circular import
-        import matplotlib.pyplot as plt
+        # Handle the edge case where this function is called
+        # without matplolib or
+        # with a masker having report capabilities disabled
+        if not is_matplotlib_installed() or not self._has_report_data():
+            return None
 
         from nilearn.reporting.utils import figure_to_png_base64
 
-        # Handle the edge case where this function is
-        # called with a masker having report capabilities disabled
-        if self._reporting_data is None:
-            return [None]
-
         fig = self._create_figure_for_report()
 
         if not fig:
-            return [None]
+            return None
 
-        plt.close()
-
-        init_display = figure_to_png_base64(fig)
-
-        return [init_display]
+        return figure_to_png_base64(fig)
 
     def _create_figure_for_report(self):
         """Generate figure to include in the report.
 
         Returns
         -------
-        None, :class:`~matplotlib.figure.Figure` or\
-              :class:`~nilearn.plotting.displays.PlotlySurfaceFigure`
-            Returns ``None`` in case the masker was not fitted.
+        list of :class:`~matplotlib.figure.Figure` or None
         """
-        # avoid circular import
-        import matplotlib.pyplot as plt
-
-        from nilearn.plotting import plot_surf, plot_surf_contours
-
         if not self._reporting_data["images"] and not getattr(
             self, "mask_img_", None
         ):
             return None
 
-        background_data = self.mask_img_
+        img = self.mask_img_
         vmin = None
         vmax = None
         if self._reporting_data["images"]:
-            background_data = self._reporting_data["images"]
-            background_data = mean_img(background_data)
-            vmin, vmax = background_data.data._get_min_max()
+            img = self._reporting_data["images"]
+            img = mean_img(img)
+            vmin, vmax = img.data._get_min_max()
 
-        views = ["lateral", "medial"]
-        hemispheres = ["left", "right"]
-
-        fig, axes = plt.subplots(
-            len(views),
-            len(hemispheres),
-            subplot_kw={"projection": "3d"},
-            figsize=(20, 20),
-            **constrained_layout_kwargs(),
+        return self._generate_figure(
+            img=img, roi_map=self.mask_img_, vmin=vmin, vmax=vmax
         )
-        axes = np.atleast_2d(axes)
 
-        for ax_row, view in zip(axes, views):
-            for ax, hemi in zip(ax_row, hemispheres):
-                plot_surf(
-                    surf_map=background_data,
-                    hemi=hemi,
-                    view=view,
-                    figure=fig,
-                    axes=ax,
-                    cmap=self.cmap,
-                    vmin=vmin,
-                    vmax=vmax,
-                    darkness=None,
+    def _set_contour_colors(self, hemi) -> str | list[str] | None:
+        """Set the colors for the contours in the report."""
+        if hemi in ["left", "right"]:
+            n_regions = len(np.unique(self.mask_img_.data.parts[hemi]))
+        else:
+            n_regions = len(
+                np.unique(
+                    np.concatenate(
+                        [
+                            self.mask_img_.data.parts["left"],
+                            self.mask_img_.data.parts["right"],
+                        ]
+                    )
                 )
+            )
 
-                colors = None
-                n_regions = len(np.unique(self.mask_img_.data.parts[hemi]))
-                if n_regions == 1:
-                    colors = "b"
-                elif n_regions == 2:
-                    colors = ["w", "b"]
-
-                plot_surf_contours(
-                    roi_map=self.mask_img_,
-                    hemi=hemi,
-                    view=view,
-                    figure=fig,
-                    axes=ax,
-                    colors=colors,
-                )
-
-        return fig
+        if n_regions == 1:
+            return "b"
+        elif n_regions == 2:
+            return ["w", "b"]
+        else:
+            return None
