@@ -6,7 +6,6 @@ test_masking.py and test_signal.py for details.
 """
 
 from copy import deepcopy
-from typing import Union
 
 import numpy as np
 import pandas as pd
@@ -61,7 +60,7 @@ else:
         check(estimator)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "estimator, check, name",
     nilearn_check_estimator(
@@ -73,6 +72,7 @@ def test_check_estimator_nilearn(estimator, check, name):  # noqa: ARG001
     check(estimator)
 
 
+@pytest.mark.slow
 def test_nifti_labels_masker(
     affine_eye, shape_3d_default, n_regions, length, img_labels
 ):
@@ -98,13 +98,18 @@ def test_nifti_labels_masker(
     # Check attributes defined at fit
     assert masker.n_elements_ == n_regions
 
-    # now with mask_img
+    # transform
+    signals = masker.fit_transform(fmri_img)
+
+    assert signals.shape == (length, n_regions)
+
+    # now with a mask_img that excludes one region
     masker = NiftiLabelsMasker(
         img_labels, mask_img=mask11_img, resampling_target=None
     )
     signals = masker.fit_transform(fmri_img)
 
-    assert signals.shape == (length, n_regions)
+    assert signals.shape == (length, n_regions - 1)
 
 
 def test_nifti_labels_masker_errors(
@@ -135,10 +140,10 @@ def test_nifti_labels_masker_errors(
     # Test all kinds of mismatch between shapes and between affines
     masker11.fit()
     with pytest.raises(
-        ValueError, match="Images have different affine matrices."
+        ValueError, match=r"Images have different affine matrices."
     ):
         masker11.transform(fmri12_img)
-    with pytest.raises(ValueError, match="Images have incompatible shapes."):
+    with pytest.raises(ValueError, match=r"Images have incompatible shapes."):
         masker11.transform(fmri21_img)
 
     masker11 = NiftiLabelsMasker(
@@ -159,18 +164,13 @@ def test_nifti_labels_masker_errors(
 
 
 def test_nifti_labels_masker_with_nans_and_infs(
-    affine_eye, shape_3d_default, n_regions, length, img_labels
+    affine_eye, n_regions, length, img_labels, img_fmri
 ):
     """Deal with NaNs and infs in label image.
 
     The masker should replace those NaNs and infs with zeros,
     while raising a warning.
     """
-    fmri_img, mask_img = generate_random_img(
-        (*shape_3d_default, length),
-        affine=affine_eye,
-    )
-
     # Introduce nans with data type float
     # See issue: https://github.com/nilearn/nilearn/issues/2580
     data = get_data(img_labels).astype(np.float32)
@@ -178,44 +178,47 @@ def test_nifti_labels_masker_with_nans_and_infs(
     data[:, :, 4] = np.inf
     img_labels = Nifti1Image(data, affine_eye)
 
-    masker = NiftiLabelsMasker(img_labels, mask_img=mask_img)
+    # image also contains 0, inf and nan
+    unique = np.unique(data)
+    assert len(unique) == n_regions + 3
+
+    masker = NiftiLabelsMasker(img_labels)
 
     with pytest.warns(UserWarning, match="Non-finite values detected."):
-        sig = masker.fit_transform(fmri_img)
+        sig = masker.fit_transform(img_fmri)
+
+    assert "nan" not in masker.lut_.name.to_list()
+    assert "inf" not in masker.lut_.name.to_list()
+    assert "unknown" not in masker.lut_.name.to_list()
 
-    assert sig.shape == (length, n_regions)
     assert np.all(np.isfinite(sig))
+    assert sig.shape == (length, n_regions)
 
 
 def test_nifti_labels_masker_with_nans_and_infs_in_data(
-    affine_eye, shape_3d_default, n_regions, length, img_labels
+    affine_eye, img_fmri, n_regions, length, img_labels
 ):
     """Apply a NiftiLabelsMasker to 4D data containing NaNs and infs.
 
     The masker should replace those NaNs and infs with zeros,
     while raising a warning.
     """
-    fmri_img, mask_img = generate_random_img(
-        (*shape_3d_default, length),
-        affine=affine_eye,
-    )
-
     # Introduce nans with data type float
     # See issues:
     # - https://github.com/nilearn/nilearn/issues/2580 (why floats)
     # - https://github.com/nilearn/nilearn/issues/2711 (why test)
-    fmri_data = get_data(fmri_img).astype(np.float32)
+    fmri_data = get_data(img_fmri).astype(np.float32)
     fmri_data[:, :, 7, :] = np.nan
     fmri_data[:, :, 4, 0] = np.inf
     fmri_img = Nifti1Image(fmri_data, affine_eye)
 
-    masker = NiftiLabelsMasker(img_labels, mask_img=mask_img)
+    masker = NiftiLabelsMasker(img_labels)
 
     with pytest.warns(UserWarning, match="Non-finite values detected."):
         sig = masker.fit_transform(fmri_img)
 
-    assert sig.shape == (length, n_regions)
     assert np.all(np.isfinite(sig))
+    assert sig.shape == (length, n_regions)
 
 
 @pytest.mark.parametrize(
@@ -268,7 +271,7 @@ def test_nifti_labels_masker_reduction_strategies_error(affine_eye):
 
     labels = Nifti1Image(labels_data, affine_eye)
 
-    with pytest.raises(ValueError, match="Invalid strategy 'TESTRAISE'"):
+    with pytest.raises(ValueError, match="'strategy' must be one of"):
         masker = NiftiLabelsMasker(labels, strategy="TESTRAISE")
         masker.fit()
 
@@ -277,14 +280,14 @@ def test_nifti_labels_masker_resampling_errors(img_labels):
     """Test errors of resampling in NiftiLabelsMasker."""
     with pytest.raises(
         ValueError,
-        match="invalid value for 'resampling_target' parameter: mask",
+        match="'resampling_target' must be one of",
     ):
         masker = NiftiLabelsMasker(img_labels, resampling_target="mask")
         masker.fit()
 
     with pytest.raises(
         ValueError,
-        match="invalid value for 'resampling_target' parameter: invalid",
+        match="'resampling_target' must be one of",
     ):
         masker = NiftiLabelsMasker(
             img_labels,
@@ -320,6 +323,7 @@ def test_nifti_labels_masker_resampling_to_data(affine_eye, n_regions, length):
     assert_array_equal(masker.labels_img_.affine, affine2)
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("resampling_target", ["data", "labels"])
 def test_nifti_labels_masker_resampling(
     affine_eye,
@@ -369,6 +373,7 @@ def test_nifti_labels_masker_resampling(
     assert_array_equal(get_data(compressed_img), get_data(compressed_img2))
 
 
+@pytest.mark.slow
 def test_nifti_labels_masker_resampling_to_labels(
     affine_eye, shape_3d_default, n_regions, length
 ):
@@ -408,6 +413,7 @@ def test_nifti_labels_masker_resampling_to_labels(
     assert fmri11_img_r.shape == (masker.labels_img_.shape[:3] + (length,))
 
 
+@pytest.mark.slow
 def test_nifti_labels_masker_resampling_to_clipped_labels(
     affine_eye, shape_3d_default, n_regions, length
 ):
@@ -433,7 +439,10 @@ def test_nifti_labels_masker_resampling_to_clipped_labels(
     )
 
     masker = NiftiLabelsMasker(
-        labels33_img, mask_img=mask22_img, resampling_target="labels"
+        labels33_img,
+        mask_img=mask22_img,
+        resampling_target="labels",
+        keep_masked_labels=True,
     )
 
     signals = masker.fit_transform(fmri11_img)
@@ -488,46 +497,7 @@ def test_nifti_labels_masker_resampling_to_none(
         masker.fit_transform(fmri_img)
 
 
-def test_standardization(rng, affine_eye, shape_3d_default, img_labels):
-    """Check output properly standardized with 'standardize' parameter."""
-    n_samples = 400
-
-    signals = rng.standard_normal(size=(np.prod(shape_3d_default), n_samples))
-    means = (
-        rng.standard_normal(size=(np.prod(shape_3d_default), 1)) * 50 + 1000
-    )
-    signals += means
-    img = Nifti1Image(
-        signals.reshape((*shape_3d_default, n_samples)), affine_eye
-    )
-
-    # Unstandarized
-    masker = NiftiLabelsMasker(img_labels, standardize=False)
-    unstandarized_label_signals = masker.fit_transform(img)
-
-    # z-score
-    masker = NiftiLabelsMasker(img_labels, standardize="zscore_sample")
-    trans_signals = masker.fit_transform(img)
-
-    assert_almost_equal(trans_signals.mean(0), 0)
-    assert_almost_equal(trans_signals.std(0), 1, decimal=3)
-
-    # psc
-    masker = NiftiLabelsMasker(img_labels, standardize="psc")
-    trans_signals = masker.fit_transform(img)
-
-    assert_almost_equal(trans_signals.mean(0), 0)
-    assert_almost_equal(
-        trans_signals,
-        (
-            unstandarized_label_signals
-            / unstandarized_label_signals.mean(0)
-            * 100
-            - 100
-        ),
-    )
-
-
+@pytest.mark.slow
 def test_nifti_labels_masker_with_mask(
     shape_3d_default, affine_eye, length, img_labels
 ):
@@ -580,7 +550,7 @@ def check_region_names_after_fit(
     masker: NiftiLabelsMasker,
     signals: np.ndarray,
     region_names: list[str],
-    background: Union[str, None],
+    background: str | None,
     resampling: bool = False,
 ):
     """Perform several checks on the expected attributes of the masker.
@@ -818,6 +788,7 @@ def test_regions_id_names_lut(affine_eye, shape_3d_default):
     check_lut(masker, expected_lut)
 
 
+@pytest.mark.slow
 def test_regions_id_names_lut_too_few(affine_eye, shape_3d_default):
     """Check passing LUT with too few entries."""
     atlas = np.zeros((8, 8, 8))
@@ -926,7 +897,7 @@ def test_check_labels_errors(shape_3d_default, affine_eye):
         shape_3d_default, affine=affine_eye, n_regions=2
     )
 
-    with pytest.raises(TypeError, match="'labels' must be a list."):
+    with pytest.raises(TypeError, match=r"'labels' must be a list."):
         NiftiLabelsMasker(labels_img, labels={"foo", "bar", "baz"}).fit()
 
     with pytest.raises(
@@ -936,6 +907,7 @@ def test_check_labels_errors(shape_3d_default, affine_eye):
         masker.fit()
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "background",
     [
@@ -998,6 +970,7 @@ def test_region_names(
     )
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize(
     "background",
     [None, "background", "Background"],
@@ -1142,6 +1115,7 @@ def test_more_labels_than_actual_region_in_atlas(
     assert len(masker.lut_) == n_regions + 1
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("background", [None, "Background"])
 def test_pass_lut(
     shape_3d_default, affine_eye, n_regions, img_labels, tmp_path, background
@@ -1227,3 +1201,43 @@ def test_no_background(n_regions, img_labels, shape_3d_default, affine_eye):
     assert len(masker.labels_) == n_expected_regions
     assert len(masker.region_ids_) == n_expected_regions
     assert len(masker.region_names_) == n_expected_regions
+
+
+@pytest.mark.parametrize(
+    "lut",
+    [
+        pd.Series({0: "Background", 1: "Frontal", 2: "Temporal"}).reset_index(
+            name="name"
+        ),  # Correct lut
+        pd.Series({1: "Frontal", 2: "Temporal", 0: "Background"}).reset_index(
+            name="name"
+        ),  # Correct lut but wrong order
+        pd.Series({0: "background", 1: "Frontal", 2: "Temporal"}).reset_index(
+            name="name"
+        ),  # Background not capitalized
+        pd.Series({1: "Frontal", 0: "background", 2: "Temporal"}).reset_index(
+            name="name"
+        ),  # Background not capitalized and wrong order
+        pd.Series({0: "unknown", 1: "Frontal", 2: "Temporal"}).reset_index(
+            name="name"
+        ),  # Background other label
+        pd.Series({1: "Frontal", 0: "unknown", 2: "Temporal"}).reset_index(
+            name="name"
+        ),  # Background other label and wrong order
+    ],
+)
+def test_lut_shift(lut):
+    """Test order of labels in lut.
+
+    Regression test for https://github.com/nilearn/nilearn/issues/5813
+    """
+    # Labels: 0=background, 1=Frontal, 2=Temporal
+    labels_data = np.zeros((4, 4, 4), dtype=np.int32)
+    labels_data[0:2, :, :] = 1  # top half = region 1
+    labels_data[2:, :, :] = 2  # bottom half = region 2
+    labels_img = Nifti1Image(labels_data, affine=np.eye(4))
+
+    masker = NiftiLabelsMasker(labels_img=labels_img, lut=lut).fit()
+
+    assert masker.region_names_ == {0: "Frontal", 1: "Temporal"}
+    assert masker.lut_["name"].to_list() == ["Frontal", "Temporal"]
