@@ -154,7 +154,7 @@ def test_check_surface_plotting_inputs_errors(surf_img_1d):
     with pytest.raises(TypeError, match="must be a SurfaceImage instance"):
         check_surface_plotting_inputs(surf_map=1, surf_mesh=None)
     with pytest.raises(
-        TypeError, match="'surf_mesh' cannot be a SurfaceImage instance."
+        TypeError, match=r"'surf_mesh' cannot be a SurfaceImage instance."
     ):
         check_surface_plotting_inputs(
             surf_map=surf_img_1d, surf_mesh=surf_img_1d
@@ -190,7 +190,7 @@ def test_check_surface_plotting_hemi_both_all_inputs(surf_img_1d, surf_mesh):
 def test_check_surface_plotting_hemi_both_mesh_none(surf_img_1d):
     """Test that hemi="both" works as expected when mesh is not provided."""
     hemi = "both"
-    combined_map, combined_mesh, combined_bg = check_surface_plotting_inputs(
+    _, combined_mesh, _ = check_surface_plotting_inputs(
         surf_map=surf_img_1d,
         surf_mesh=None,
         hemi=hemi,
@@ -202,9 +202,7 @@ def test_check_surface_plotting_hemi_both_mesh_none(surf_img_1d):
 
 def test_check_surface_plotting_hemi_error(surf_img_1d, surf_mesh):
     """Test that an error is raised when hemi is not valid."""
-    with pytest.raises(
-        ValueError, match="hemi must be one of 'left', 'right' or 'both'"
-    ):
+    with pytest.raises(ValueError, match="'hemi' must be one of"):
         check_surface_plotting_inputs(
             surf_map=surf_img_1d, surf_mesh=surf_mesh, hemi="foo"
         )
@@ -241,7 +239,7 @@ def test_bg_data_error():
 def test_get_faces_on_edge_matplotlib(in_memory_mesh):
     _, faces = load_surf_mesh(in_memory_mesh)
     with pytest.raises(
-        ValueError, match=("Vertices in parcellation do not form region.")
+        ValueError, match=(r"Vertices in parcellation do not form region.")
     ):
         get_faces_on_edge(faces, [91])
 
@@ -274,5 +272,5 @@ def test_get_surface_backend_unknown_error():
     """Tests to see if get_surface_backend raises error when the specified
     backend is not implemented.
     """
-    with pytest.raises(ValueError, match="Unknown plotting engine"):
+    with pytest.raises(ValueError, match="'engine' must be one of"):
         get_surface_backend("unknown")
