@@ -7,6 +7,7 @@ features
 
 import warnings
 from pathlib import Path
+from typing import Literal
 
 import numpy as np
 import pandas as pd
@@ -16,14 +17,16 @@ from scipy.interpolate import CubicSpline
 from sklearn.utils import as_float_array, gen_even_slices
 
 from nilearn._utils.docs import fill_doc
-from nilearn._utils.exceptions import AllVolumesRemovedError
 from nilearn._utils.helpers import stringify_path
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.numpy_conversions import as_ndarray, csv_to_array
 from nilearn._utils.param_validation import (
+    check_is_of_allowed_type,
+    check_parameter_in_allowed,
     check_params,
     check_run_sample_masks,
 )
+from nilearn.exceptions import AllVolumesRemovedError
 
 __all__ = [
     "butterworth",
@@ -34,11 +37,12 @@ __all__ = [
 available_filters = ("butterworth", "cosine")
 
 
+@fill_doc
 def standardize_signal(
     signals,
-    detrend=False,
-    standardize="zscore",
-):
+    detrend: bool = False,
+    standardize: Literal["zscore", "psc", "zscore_sample"] | None = "zscore",
+) -> np.ndarray:
     """Center and standardize a given signal (time is along first axis).
 
     Parameters
@@ -49,33 +53,25 @@ def standardize_signal(
     detrend : :obj:`bool`, default=False
         If detrending of timeseries is requested.
 
-    standardize : {'zscore_sample', 'zscore', 'psc', True, False}, \
-                  default='zscore'
-        Strategy to standardize the signal:
-
-            - 'zscore_sample': The signal is z-scored. Timeseries are shifted
-              to zero mean and scaled to unit variance. Uses sample std.
-            - 'zscore': The signal is z-scored. Timeseries are shifted
-              to zero mean and scaled to unit variance. Uses population std
-              by calling :obj:`numpy.std` with N - ``ddof=0``.
-            - 'psc':  Timeseries are shifted to zero mean value and scaled
-              to percent signal change (as compared to original mean signal).
-            - True: The signal is z-scored (same as option `zscore`).
-              Timeseries are shifted to zero mean and scaled to unit variance.
-            - False: Do not standardize the data.
-
+    %(standardize_zscore)s
 
     Returns
     -------
     std_signals : :class:`numpy.ndarray`
         Copy of signals, standardized.
     """
-    if standardize not in [True, False, "psc", "zscore", "zscore_sample"]:
-        raise ValueError(f"{standardize} is no valid standardize strategy.")
+    check_params(locals())
 
     signals = _detrend(signals, inplace=False) if detrend else signals.copy()
 
-    if standardize:
+    assert not isinstance(standardize, bool)
+
+    if standardize is not None:
+        check_parameter_in_allowed(
+            standardize,
+            allowed=["psc", "zscore", "zscore_sample"],
+            parameter_name="standardize",
+        )
         if signals.shape[0] == 1:
             warnings.warn(
                 "Standardization of 3D signal has been requested but "
@@ -94,19 +90,22 @@ def standardize_signal(
             std[std < np.finfo(np.float64).eps] = 1.0
             signals /= std
 
-        elif (standardize == "zscore") or (standardize is True):
-            # TODO (nilearn >= 0.13.0) deprecate nearest interpolation
+        elif standardize == "zscore":
+            # TODO (nilearn >= 0.14.0) change default to 'zscore'
             std_strategy_default = (
                 "The default strategy for standardize is currently 'zscore' "
                 "which incorrectly uses population std to calculate sample "
                 "zscores. The new strategy 'zscore_sample' corrects this "
-                "behavior by using the sample std. In release 0.13, the "
-                "default strategy will be replaced by the new strategy and "
-                "the 'zscore' option will be removed. Please use "
-                "'zscore_sample' instead."
+                "behavior by using the sample std. "
+                "In release 0.14.0, the default strategy "
+                "will be replaced by the new strategy, "
+                "the 'zscore' option will be removed. "
+                "and using standardize=True will fall back "
+                "to 'zscore_sample'."
+                "To avoid this warning, please use 'zscore_sample' instead."
             )
             warnings.warn(
-                category=DeprecationWarning,
+                category=FutureWarning,
                 message=std_strategy_default,
                 stacklevel=find_stack_level(),
             )
@@ -565,7 +564,7 @@ def clean(
     high_pass=None,
     t_r=2.5,
     ensure_finite=False,
-    extrapolate=True,
+    extrapolate=False,
     **kwargs,
 ):
     """Improve :term:`SNR` on masked :term:`fMRI` signals.
@@ -645,7 +644,7 @@ def clean(
         information, sample_mask must be a list containing sets of indexes for
         each run.
 
-        .. versionadded:: 0.8.0
+        .. nilearn_versionadded:: 0.8.0
 
     %(t_r)s
         Default=2.5.
@@ -663,25 +662,8 @@ def clean(
 
     %(high_pass)s
     %(detrend)s
-    standardize : {'zscore_sample', 'zscore', 'psc', True, False}, \
-                  default="zscore"
-        Strategy to standardize the signal:
 
-        - 'zscore_sample':
-          The signal is z-scored.
-          Timeseries are shifted to zero mean and scaled to unit variance.
-          Uses sample std.
-        - 'zscore':
-          The signal is z-scored.
-          Timeseries are shifted to zero mean and scaled to unit variance.
-          Uses population std by calling :obj:`numpy.std` with N - ``ddof=0``.
-        - 'psc':
-          Timeseries are shifted to zero mean value and scaled
-          to percent signal change (as compared to original mean signal).
-        - True:
-          The signal is z-scored (same as option `zscore`).
-          Timeseries are shifted to zero mean and scaled to unit variance.
-        - False: Do not standardize the data.
+    %(standardize_zscore)s
 
     %(standardize_confounds)s
 
@@ -689,11 +671,14 @@ def clean(
         If `True`, the non-finite values (NANs and infs) found in the data
         will be replaced by zeros.
 
-    extrapolate : :obj:`bool`, default=True
+    extrapolate : :obj:`bool`, default=False
         If `True` and filter='butterworth', censored volumes in both ends of
         the signal data will be interpolated before filtering. Otherwise, they
         will be discarded from the band-pass filtering process.
 
+        .. nilearn_versionchanged:: 0.13.0dev
+            Default changed to False.
+
     kwargs : :obj:`dict`
         Keyword arguments to be passed to functions called within ``clean``.
         Kwargs prefixed with ``'butterworth__'`` will be passed to
@@ -731,8 +716,8 @@ def clean(
     filter_type = _check_filter_parameters(filter, low_pass, high_pass, t_r)
 
     # Read confounds and signals
-    signals, runs, confounds, sample_mask = _sanitize_inputs(
-        signals, runs, confounds, sample_mask, ensure_finite
+    signals, runs, confounds, sample_mask, standardize = _sanitize_inputs(
+        signals, runs, confounds, sample_mask, ensure_finite, standardize
     )
 
     # Process each run independently
@@ -769,11 +754,11 @@ def clean(
     original_mean_signals = signals.mean(axis=0)
     if detrend:
         signals = standardize_signal(
-            signals, standardize=False, detrend=detrend
+            signals, standardize=None, detrend=detrend
         )
         if confounds is not None:
             confounds = standardize_signal(
-                confounds, standardize=False, detrend=detrend
+                confounds, standardize=None, detrend=detrend
             )
 
     # Butterworth filtering
@@ -809,9 +794,37 @@ def clean(
 
     # Remove confounds
     if confounds is not None:
-        confounds = standardize_signal(
-            confounds, standardize=standardize_confounds, detrend=False
+        # TODO (nilearn >= 0.14.0)
+        # - remove DeprecationWarning
+        # - remove warnings.filterwarnings
+        # - remove comment below
+        # The following call to standardize_signal relies on the default of
+        # standardize (True) which will throw a FutureWarning
+        # that contains some actions they cannot perform
+        # as users cannot affect this call.
+        # This can be confusing because if they call clean with
+        # standardize="zscore_sample", they will get a warning to set
+        # standardize to "zscore_sample"!!!
+        # So we ignore the FutureWarning
+        # and instead throw a DeprecationWarning that's only for devs.
+        std_strategy_default = (
+            "From release 0.14.0, confounds will be standardized "
+            "using the sample std instead of the population std."
         )
+        warnings.warn(
+            category=DeprecationWarning,
+            message=std_strategy_default,
+            stacklevel=find_stack_level(),
+        )
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=FutureWarning)
+            confounds = standardize_signal(
+                confounds,
+                standardize=None
+                if standardize_confounds is False
+                else "zscore",
+                detrend=False,
+            )
         if not standardize_confounds:
             # Improve numerical stability by controlling the range of
             # confounds. We don't rely on standardize_signal as it removes any
@@ -895,20 +908,6 @@ def _censor_signals(signals, confounds, sample_mask):
 
 def _interpolate_volumes(volumes, sample_mask, t_r, extrapolate):
     """Interpolate censored volumes in signals/confounds."""
-    if extrapolate:
-        # TODO (nilearn 0.13.0)
-        extrapolate_default = (
-            "By default the cubic spline interpolator extrapolates "
-            "the out-of-bounds censored volumes in the data run. This "
-            "can lead to undesired filtered signal results. Starting in "
-            "version 0.13, the default strategy will be not to extrapolate "
-            "but to discard those volumes at filtering."
-        )
-        warnings.warn(
-            category=FutureWarning,
-            message=extrapolate_default,
-            stacklevel=find_stack_level(),
-        )
     frame_times = np.arange(volumes.shape[0]) * t_r
     remained_vol = frame_times[sample_mask]
     remained_x = volumes[sample_mask, :]
@@ -920,10 +919,55 @@ def _interpolate_volumes(volumes, sample_mask, t_r, extrapolate):
     return volumes
 
 
+def create_cosine_drift(high_pass, frame_times):
+    """Create a cosine drift matrix with frequencies or equal to high_pass.
+
+    Parameters
+    ----------
+    high_pass : :obj:`float`
+        Cut frequency of the high-pass filter in Hz
+
+    frame_times : array of shape (n_scans,)
+        The sampling times in seconds
+
+    Returns
+    -------
+    cosine_drift : array of shape(n_scans, n_drifts)
+        Cosine drifts plus a constant regressor at cosine_drift[:, -1]
+
+    References
+    ----------
+    http://en.wikipedia.org/wiki/Discrete_cosine_transform DCT-II
+
+    """
+    n_frames = len(frame_times)
+    n_times = np.arange(n_frames)
+    dt = (frame_times[-1] - frame_times[0]) / (n_frames - 1)
+    if high_pass * dt >= 0.5:
+        warnings.warn(
+            "High-pass filter will span all accessible frequencies "
+            "and saturate the design matrix. "
+            "You may want to reduce the high_pass value."
+            f"The provided value is {high_pass} Hz",
+            stacklevel=find_stack_level(),
+        )
+    order = np.minimum(
+        n_frames - 1, int(np.floor(2 * n_frames * high_pass * dt))
+    )
+    cosine_drift = np.zeros((n_frames, order + 1))
+    normalizer = np.sqrt(2.0 / n_frames)
+
+    for k in range(1, order + 1):
+        cosine_drift[:, k - 1] = normalizer * np.cos(
+            (np.pi / n_frames) * (n_times + 0.5) * k
+        )
+
+    cosine_drift[:, -1] = 1.0
+    return cosine_drift
+
+
 def _create_cosine_drift_terms(signals, confounds, high_pass, t_r):
     """Create cosine drift terms, append to confounds regressors."""
-    from nilearn.glm.first_level.design_matrix import create_cosine_drift
-
     frame_times = np.arange(signals.shape[0]) * t_r
     # remove constant, as the signal is mean centered
     cosine_drift = create_cosine_drift(high_pass, frame_times)[:, :-1]
@@ -1006,14 +1050,33 @@ def _process_runs(
     return np.vstack(cleaned_signals)
 
 
-def _sanitize_inputs(signals, runs, confounds, sample_mask, ensure_finite):
+def _sanitize_inputs(
+    signals, runs, confounds, sample_mask, ensure_finite, standardize
+):
     """Clean up signals and confounds before processing."""
     n_time = len(signals)  # original length of the signal
     n_runs, runs = _sanitize_runs(n_time, runs)
     confounds = sanitize_confounds(n_time, confounds)
     sample_mask = _sanitize_sample_mask(n_time, n_runs, runs, sample_mask)
     signals = _sanitize_signals(signals, ensure_finite)
-    return signals, runs, confounds, sample_mask
+
+    if isinstance(standardize, bool):
+        warnings.warn(
+            stacklevel=find_stack_level(),
+            category=FutureWarning,
+            message=(
+                "boolean values for 'standardize' "
+                "will be deprecated in nilearn 0.15.0.\n"
+                "Use 'zscore_sample' instead of 'True' or "
+                "use 'None' instead of 'False'."
+            ),
+        )
+        if standardize is True:
+            standardize = "zscore"
+        elif standardize is False:
+            standardize = None
+
+    return signals, runs, confounds, sample_mask, standardize
 
 
 def sanitize_confounds(n_time, confounds):
@@ -1025,10 +1088,9 @@ def sanitize_confounds(n_time, confounds):
     if confounds is None:
         return confounds
 
-    if not isinstance(confounds, (list, tuple, str, np.ndarray, pd.DataFrame)):
-        raise TypeError(
-            f"confounds keyword has an unhandled type: {confounds.__class__}"
-        )
+    check_is_of_allowed_type(
+        confounds, (list, tuple, str, np.ndarray, pd.DataFrame), "confounds"
+    )
 
     if not isinstance(confounds, (list, tuple)):
         confounds = (confounds,)
@@ -1173,11 +1235,7 @@ def _check_filter_parameters(filter, low_pass, high_pass, t_r):
 
 def _sanitize_signals(signals, ensure_finite):
     """Ensure signals are in the correct state."""
-    if not isinstance(ensure_finite, bool):
-        raise ValueError(
-            "'ensure_finite' must be boolean type True or False "
-            f"but you provided ensure_finite={ensure_finite}"
-        )
+    check_parameter_in_allowed(ensure_finite, [True, False], "ensure_finite")
     signals = signals.copy()
     if not isinstance(signals, np.ndarray):
         signals = as_ndarray(signals)
